@@ -2,6 +2,7 @@ use crate::WSClient;
 use std::collections::HashMap;
 use std::sync::{Arc, Mutex};
 
+use super::utils::{ensure_frame_size, WS_FRAME_SIZE};
 use super::{
     ws_client_internal::{MiscMessage, WSClientInternal},
     Candlestick, OrderBook, OrderBookTopK, Ticker, Trade, BBO,
@@ -15,14 +16,13 @@ const SPOT_WEBSOCKET_URL: &str = "wss://stream.binance.com:9443/stream";
 const LINEAR_WEBSOCKET_URL: &str = "wss://fstream.binance.com/stream";
 const INVERSE_WEBSOCKET_URL: &str = "wss://dstream.binance.com/stream";
 
+// https://binance-docs.github.io/apidocs/futures/en/#websocket-market-streams
 // A single connection can listen to a maximum of 200 streams
 const MAX_NUM_CHANNELS: usize = 200;
 
 // The websocket server will send a ping frame every 5 minutes
 const SERVER_PING_INTERVAL: u64 = 300;
 
-const WS_FRAME_SIZE: usize = 4096;
-
 // Internal unified client
 struct BinanceWSClient<'a> {
     client: WSClientInternal<'a>,
@@ -67,56 +67,26 @@ impl<'a> BinanceWSClient<'a> {
         }
     }
 
+    fn topics_to_command(chunk: &[String], subscribe: bool) -> String {
+        format!(
+            r#"{{"id":9527,"method":"{}","params":{}}}"#,
+            if subscribe {
+                "SUBSCRIBE"
+            } else {
+                "UNSUBSCRIBE"
+            },
+            serde_json::to_string(chunk).unwrap()
+        )
+    }
+
     fn channels_to_commands(channels: &[String], subscribe: bool) -> Vec<String> {
-        let raw_channels: Vec<&String> =
-            channels.iter().filter(|ch| !ch.starts_with('{')).collect();
-        let mut all_commands: Vec<String> = channels
-            .iter()
-            .filter(|ch| ch.starts_with('{'))
-            .map(|s| s.to_string())
-            .collect();
-
-        if !raw_channels.is_empty() {
-            let mut index = 0;
-            while index < raw_channels.len() {
-                for end in (index + 1)..(raw_channels.len() + 1) {
-                    let num_subscriptions = end - index;
-                    let chunk = &raw_channels[index..end];
-                    let command = format!(
-                        r#"{{"id":9527,"method":"{}","params":{}}}"#,
-                        if subscribe {
-                            "SUBSCRIBE"
-                        } else {
-                            "UNSUBSCRIBE"
-                        },
-                        serde_json::to_string(&chunk).unwrap()
-                    );
-                    if end == raw_channels.len() || num_subscriptions >= MAX_NUM_CHANNELS {
-                        all_commands.push(command);
-                        index = end;
-                        break;
-                    } else {
-                        let chunk = &raw_channels[index..end + 1];
-                        let command_next = format!(
-                            r#"{{"id":9527,"method":"{}","params":{}}}"#,
-                            if subscribe {
-                                "SUBSCRIBE"
-                            } else {
-                                "UNSUBSCRIBE"
-                            },
-                            serde_json::to_string(&chunk).unwrap()
-                        );
-                        if command_next.len() > WS_FRAME_SIZE {
-                            all_commands.push(command);
-                            index = end;
-                            break;
-                        }
-                    };
-                }
-            }
-        };
-
-        all_commands
+        ensure_frame_size(
+            channels,
+            subscribe,
+            Self::topics_to_command,
+            WS_FRAME_SIZE,
+            Some(MAX_NUM_CHANNELS),
+        )
     }
 
     fn on_misc_msg(msg: &str) -> MiscMessage {
