@@ -102,7 +102,7 @@ impl<'a> OrderBookTopK for BithumbWSClient<'a> {
 }
 
 impl<'a> Candlestick for BithumbWSClient<'a> {
-    fn subscribe_candlestick(&self, _pairs: &[String], _interval: u32) {
+    fn subscribe_candlestick(&self, _symbol_interval_list: &[(String, usize)]) {
         panic!("CoinbasePro does NOT have candlestick channel");
     }
 }
